
-- Cirque De La Lune Database
--------------------
-- Script revised by L. Pollacia 03/2019
--------------------
--------------------
-- DROP TABLES to allow for multiple runs
--------------------

DROP TABLE CIR_EVENT_has_CUSTOMERS;
DROP TABLE CIR_EVENT_has_performers;
DROP TABLE CIR_EVENT;
DROP TABLE CIR_PERFORMER;
DROP TABLE CIR_SPECIALTY;
DROP TABLE CIR_TEAM;
DROP TABLE CIR_CUSTOMER;
DROP TABLE CIR_LOCATION;
DROP TABLE CIR_SHOW;


--------------------
-- CREATE TABLES
--------------------
-- SHOW
CREATE TABLE CIR_SHOW (
showID      INTEGER,
showName    VARCHAR(25),
showTheme   VARCHAR(45),
showEstDate DATE,
showExpDate DATE,
-- Table-level constraints
CONSTRAINT show_showid_pk PRIMARY KEY (showid));

-- Populate CIR_SHOW
INSERT INTO CIR_show VALUES ( 
10, 'Symphonia', 'Orcestral music. Jewel colors.', '2010-10-08', '2018-10-11');

INSERT INTO CIR_show VALUES (
20, 'Mana', 'Cool colors, magenta, and yellow.', '2014-10-12', '2018-10-12');

INSERT INTO CIR_show VALUES ( 
30, 'Lune', 'Cool colors, white, black, and black light', '2016-10-07', '2019-10-10');

INSERT INTO CIR_show VALUES ( 
40, 'Eclipse', 'Bright warm colors, white, and black.', '2017-10-13', '2019-10-10');

INSERT INTO CIR_show VALUES ( 
50, 'Gravity', 'colidescope effect colors', '2018-10-12', '2020-10-10');

INSERT INTO CIR_show VALUES ( 
60, 'Mistic', 'Smoke and mirrors', '2019-03-01', '2021-03-04');

INSERT INTO CIR_show VALUES ( 
70, 'Savannah', 'African and Australian savannahs', '2019-10-11', '2021-10-07');

INSERT INTO CIR_show VALUES ( 
80, 'Peak', 'Tallest mountains on Earth', '2020-03-06', '2022-03-03');

INSERT INTO CIR_show VALUES ( 
90, 'Alien', '', '2020-10-09', '2022-10-06');

INSERT INTO CIR_show VALUES ( 
100, 'Liquid', '', '2018-03-05', '2023-03-02');


--------------------
-- LOCATION
CREATE TABLE CIR_LOCATION (
locationID      INTEGER,
locationName    VARCHAR(30) UNIQUE,
locationStreetNumber VARCHAR(10) NOT NULL,
locationStreetAddress VARCHAR(45) NOT NULL,
locationCity    VARCHAR(45) NOT NULL,
locationState   VARCHAR(25) NOT NULL,
locationPhone   VARCHAR(10)  UNIQUE,
locationEmail   VARCHAR(45)  UNIQUE,
locationCapacity INTEGER,
-- Table-level constraints
CONSTRAINT location_locationid_pk PRIMARY KEY (locationid));

-- POPULATE CIR_LOCATION
INSERT INTO CIR_location VALUES ( 101, 'Atlantic Station', '1234', '20th Street', 'Atlanta', 'Georgia', '6786786789', 'atlanta@cirquelune.com', 400 );
INSERT INTO CIR_location VALUES ( 202, 'Universal Citywalk', '6000', 'Universal Blvd', 'Orlando', 'Florida', '3213213210', 'orlando@cirquelune.com', 350 );
INSERT INTO CIR_location VALUES ( 303, 'Bayfront Park Amphitheatre', '301', 'Biscayne Blvd', 'Miami', 'Florida', '3053053056', 'miami@cirquelune.com', 350 );
INSERT INTO CIR_location VALUES ( 404, 'Discovery Green', '1500', 'McKinney St', 'Houston', 'Texas', '7137137134', 'houston@cirquelune.com', 500 );
INSERT INTO CIR_location VALUES ( 505, 'The Magic Castle ', '7001', 'Franklin Avenue', 'Hollywood', 'California', '2132132134', 'la@cirquelune.com', 500 );
INSERT INTO CIR_location VALUES ( 606, 'The Venetian', '3355', 'Neon Lights Avenue', 'Las Vegas', 'Nevada', '7027027023', 'vegas@cirquelune.com', 400 );
	
--------------------
-- CIR_CUSTOMER
CREATE TABLE CIR_CUSTOMER (
customerID      INTEGER,
customerFirstName  VARCHAR(25),
customerLastName   VARCHAR(25),
customerPhone   VARCHAR(10) UNIQUE,
customerEmail   VARCHAR(45) UNIQUE,
-- Table-level constraints
CONSTRAINT customer_customerid_pk PRIMARY KEY (customerid));

-- POPULATE CIR_CUSTOMER
INSERT INTO CIR_customer VALUES (
1, 'Martie', 'Lowin', '6167203051', 'mlowin0@accuweather.com');
INSERT INTO CIR_customer VALUES (
2, 'Marge', 'Littrick', '2713152253', 'mlittrick1@hubpages.com');
INSERT INTO CIR_customer VALUES (
3, 'Karoly', 'Potten', '6141095514', 'kpotten2@i2i.jp');
INSERT INTO CIR_customer VALUES (
4, 'Astrid', 'Dagworthy', '9713661363', 'adagworthy3@archive.org');
INSERT INTO CIR_customer VALUES (
5, 'Jacinda', 'Ffoulkes', '7614315978', 'jffoulkes4@google.fr');
INSERT INTO CIR_customer VALUES (
6, 'Shelba', 'Bidnall', '5048328115', 'sbidnall5@wsj.com');
INSERT INTO CIR_customer VALUES (
7, 'Mack', 'Ribou', '6469846018', 'mribou6@xing.com');
INSERT INTO CIR_customer VALUES (
8, 'Sarene', 'Haughian', '9086399006', 'shaughian7@networksolutions.com');
INSERT INTO CIR_customer VALUES (
9, 'Verne', 'Breakey', '6408512926', 'vbreakey8@bravesites.com');
INSERT INTO CIR_customer VALUES (
10, 'Son', 'Hegarty', '5131677928', 'shegarty9@spotify.com');
INSERT INTO CIR_customer VALUES (
11, 'Maynord', 'Scarbarrow', '8905892862', 'mscarbarrowrn@cyberchimps.com');
INSERT INTO CIR_customer VALUES (
12, 'Lotti', 'Farish', '3288740916', 'lfarishro@miitbeian.gov.cn');
INSERT INTO CIR_customer VALUES (
13, 'Brigit', 'Cashell', '6088496481', 'bcashellrp@skyrock.com');
INSERT INTO CIR_customer VALUES (
14, 'Cherrita', 'Odams', '2087487846', 'codamsrq@webeden.co.uk');
INSERT INTO CIR_customer VALUES (
15, 'Kimmie', 'Gallaher', '1747689652', 'kgallaherrr@redcross.org');


--------------------
-- CIR_TEAM
CREATE TABLE CIR_TEAM (
teamID     INTEGER,
teamName   VARCHAR(25) UNIQUE,
teamTheme  VARCHAR(25),
CONSTRAINT team_teamid_pk PRIMARY KEY (teamid));

-- POPULATE CIR_TEAM
INSERT INTO CIR_team VALUES ( 
100, 'Chimera', 'Alchemy' );
INSERT INTO CIR_team VALUES ( 
200, 'Unicorn', 'Mystery');
INSERT INTO CIR_team VALUES ( 
300, 'Griffin', 'Courage');
INSERT INTO CIR_team VALUES ( 
400, 'Dragon', 'Power');
INSERT INTO CIR_team VALUES ( 
500, 'Pheonix', 'Resurection');
INSERT INTO CIR_team VALUES ( 
600, 'Mermaid', 'Illusion');
INSERT INTO CIR_team VALUES ( 
700, 'Siren', 'Confusion');
INSERT INTO CIR_team VALUES ( 
800, 'Hydra', 'Immortality' );

--------------------
-- SPECIALTY
CREATE TABLE CIR_SPECIALTY (
specialtyID     INTEGER,
specialtyName   VARCHAR(25) UNIQUE,
specialtyType   VARCHAR(45),
specialtyEquipment VARCHAR(25),
-- Table-level constraints
CONSTRAINT specialty_specialtyid_pk PRIMARY KEY (specialtyid),
CONSTRAINT specialty_specequipment_ck
    CHECK (
        UPPER(specialtyequipment) IN ('NONE', 'LITE', 'MEDIUM', 'HEAVY')));

-- POPULATE CIR_SPECIALTY
INSERT INTO CIR_specialty VALUES ( 100, 'Contortionist', 'Amaze', 'NONE');
INSERT INTO CIR_specialty VALUES ( 200, 'Singer', 'Musical', 'LITE');
INSERT INTO CIR_specialty VALUES ( 300, 'Clown', 'Humor', 'HEAVY');
INSERT INTO CIR_specialty VALUES ( 400, 'Athlete', 'Body', 'LITE');
INSERT INTO CIR_specialty VALUES ( 500, 'Dancer', 'Body', 'NONE');
INSERT INTO CIR_specialty VALUES ( 600, 'Instrumentalist', 'Musical', 'NONE');
INSERT INTO CIR_specialty VALUES ( 700, 'Actor', 'Body', 'NONE');
INSERT INTO CIR_specialty VALUES ( 800, 'Slackline', 'Amaze', 'Medium');
INSERT INTO CIR_specialty VALUES ( 900, 'Martial Artist', 'Body', 'Medium');
INSERT INTO CIR_specialty VALUES ( 1000, 'Trapeze', 'Amaze', 'Heavy');
INSERT INTO CIR_specialty VALUES ( 1100, 'Juggler', 'Amaze', 'Medium');



--------------------
-- Performer
CREATE TABLE CIR_PERFORMER (
performerID         INTEGER,
performerNickName   VARCHAR(35),
performerFirstName  VARCHAR(25),
performerLastName   VARCHAR(25),
performerBirthDate  DATE,
performerspecialtyLevel INTEGER,
specialtyID         INTEGER,
teamID             INTEGER,
-- Table-level constraints
CONSTRAINT performer_performerid_pk PRIMARY KEY (performerid),
CONSTRAINT performer_specialtyid_fk FOREIGN KEY (specialtyid)   REFERENCES CIR_specialty(specialtyid),
CONSTRAINT team_teamid_fk           FOREIGN KEY (teamid)        REFERENCES CIR_team(teamid));
    
-- POPULATE PERFORMER
INSERT INTO CIR_performer VALUES (
1, 'Long-finned pilot whale', 'Reinold', 'Timblett', '1989-10-15', 1, 600, 700);
INSERT INTO CIR_performer VALUES (
2, 'Cat, tiger', 'Kalinda', 'Hanburry', '1993-10-31', 7, 1000, 700);
INSERT INTO CIR_performer VALUES (
3, 'Skink, blue-tongued', 'Salvador', 'Agnolo', '1988-04-13', 9, 1000, 700);
INSERT INTO CIR_performer VALUES (
4, 'Grenadier, purple', 'Lula', 'Hellings', '1986-04-15', 5, 1100, 600);
INSERT INTO CIR_performer VALUES (
5, 'Sandpiper, spotted wood', 'Urbano', 'Hirsch', '1988-02-21', 0, 1000, 800);
INSERT INTO CIR_performer VALUES (
6, 'Lizard, blue-tongued', 'Pedro', 'Darragh', '1995-10-21', 9, 900, 800);
INSERT INTO CIR_performer VALUES (
7, 'Polecat, african', 'Bonita', 'Dominguez', '1998-06-11', 0, 700, 800);
INSERT INTO CIR_performer VALUES (
8, 'Lesser masked weaver', 'Neal', 'Ell',  '1996-05-17', 9, 1000, 100);
INSERT INTO CIR_performer VALUES (
9, 'Gecko, bent-toed', 'Issie', 'Norree', '1990-04-30', 8, 1000, 600);
INSERT INTO CIR_performer VALUES (
10, 'Bateleur eagle', 'Amanda', 'Drynan', '1985-02-03',  0, 1000, 100);
INSERT INTO CIR_performer VALUES (
11, 'Avocet, pied', 'Myra', 'Krolik', '1999-06-20', 6, 900, 800);
INSERT INTO CIR_performer VALUES (
12, 'Smith''s bush squirrel', 'Willi', 'Quinane', '1995-11-19', 0, 1000, 600);
INSERT INTO CIR_performer VALUES (
13, 'White-bellied sea eagle', 'Joy', 'Canniffe', '1987-05-13', 3, 600, 700);
INSERT INTO CIR_performer VALUES (
14, 'Black-footed ferret', 'Starr', 'Berkely', '1998-03-04', 9, 800, 600);
INSERT INTO CIR_performer VALUES (
15, 'Stork, marabou', 'Walker', 'Symcoxe', '1999-07-23', 6, 1000, 800);

   
--------------------
-- EVENT
CREATE TABLE CIR_EVENT (
eventID     INTEGER,
showID      INTEGER,
locationID  INTEGER,
eventDate   DATE NOT NULL,
-- Table-level constraints
CONSTRAINT event_eventid_pk PRIMARY KEY (eventid),
CONSTRAINT event_showid_fk     FOREIGN KEY (showid)     
             REFERENCES CIR_show(showid),
CONSTRAINT event_locationid_fk FOREIGN KEY (locationid) 
             REFERENCES CIR_location(locationid));

-- POPULATE CIR_EVENT
INSERT INTO CIR_event VALUES (1, 10, 101, '2019-06-28');
INSERT INTO CIR_event VALUES (2, 10, 101, '2011-09-28');
INSERT INTO CIR_event VALUES (3, 10, 202, '2012-06-27');
INSERT INTO CIR_event VALUES (4, 10, 303, '2015-02-06');
INSERT INTO CIR_event VALUES (5, 50, 101, '2016-05-29');
INSERT INTO CIR_event VALUES (6, 10, 101, '2017-05-29');
INSERT INTO CIR_event VALUES (7, 10, 202, '2018-05-08');
INSERT INTO CIR_event VALUES (8, 10, 505, '2019-10-31');
INSERT INTO CIR_event VALUES (9, 10, 606, '2018-02-12');
INSERT INTO CIR_event VALUES (10, 40, 404, '2018-01-19');
INSERT INTO CIR_event VALUES (11, 30, 606, '2018-10-22');
INSERT INTO CIR_event VALUES (12, 40, 606, '2019-10-15');
INSERT INTO CIR_event VALUES (13, 30, 606, '2018-05-06');
INSERT INTO CIR_event VALUES (14, 40, 202, '2019-11-11');

--------------------
-- EVENT_has_performers
CREATE TABLE CIR_EVENT_has_performers (
eventID     INTEGER,
performerID INTEGER,
-- Table-level constraints
CONSTRAINT ehp_pk PRIMARY KEY(eventID, performerID),
CONSTRAINT ehp_eventid_fk     FOREIGN KEY (eventid)     REFERENCES CIR_event(eventid),
CONSTRAINT ehp_performerid_fk FOREIGN KEY (performerid) REFERENCES CIR_performer(performerid));

-- POPULATE EVENT_has_performers
INSERT INTO CIR_event_has_performers VALUES (1, 1);
INSERT INTO CIR_event_has_performers VALUES (1, 2);
INSERT INTO CIR_event_has_performers VALUES (1, 3);
INSERT INTO CIR_event_has_performers VALUES (1, 4);
INSERT INTO CIR_event_has_performers VALUES (1, 5);
INSERT INTO CIR_event_has_performers VALUES (1, 6);
INSERT INTO CIR_event_has_performers VALUES (1, 7);
INSERT INTO CIR_event_has_performers VALUES (1, 8);
INSERT INTO CIR_event_has_performers VALUES (1, 9);
INSERT INTO CIR_event_has_performers VALUES (1, 10);
INSERT INTO CIR_event_has_performers VALUES (2, 1);
INSERT INTO CIR_event_has_performers VALUES (2, 2);
INSERT INTO CIR_event_has_performers VALUES (2, 3);
INSERT INTO CIR_event_has_performers VALUES (2, 14);
INSERT INTO CIR_event_has_performers VALUES (2, 15);
INSERT INTO CIR_event_has_performers VALUES (3, 1);
INSERT INTO CIR_event_has_performers VALUES (3, 4);
INSERT INTO CIR_event_has_performers VALUES (3, 8);
INSERT INTO CIR_event_has_performers VALUES (3, 9);
INSERT INTO CIR_event_has_performers VALUES (3, 10);
INSERT INTO CIR_event_has_performers VALUES (1, 12);
INSERT INTO CIR_event_has_performers VALUES (1, 13);
INSERT INTO CIR_event_has_performers VALUES (4, 3);
INSERT INTO CIR_event_has_performers VALUES (4, 4);
INSERT INTO CIR_event_has_performers VALUES (4, 5);
INSERT INTO CIR_event_has_performers VALUES (4, 6);
INSERT INTO CIR_event_has_performers VALUES (7, 1);

--------------------
-- EVENT_has_CUSTOMERS
CREATE TABLE CIR_EVENT_has_CUSTOMERS (
eventID    INTEGER,
customerID  INTEGER,
-- Table-level constraints
CONSTRAINT ehc_pk PRIMARY KEY (eventID, customerID),
CONSTRAINT ehc_eventid_fk    FOREIGN KEY (eventid)    REFERENCES CIR_event(eventid),
CONSTRAINT ehc_customerid_fk FOREIGN KEY (customerid) REFERENCES CIR_customer(customerid));

-- POPULATE EVENT_has_Customers
INSERT INTO CIR_event_has_customers VALUES (1, 1);
INSERT INTO CIR_event_has_customers VALUES (1, 2);
INSERT INTO CIR_event_has_customers VALUES (1, 5);
INSERT INTO CIR_event_has_customers VALUES (1, 6);
INSERT INTO CIR_event_has_customers VALUES (2, 3);
INSERT INTO CIR_event_has_customers VALUES (2, 12);
INSERT INTO CIR_event_has_customers VALUES (4, 4);
INSERT INTO CIR_event_has_customers VALUES (5, 5);
INSERT INTO CIR_event_has_customers VALUES (5, 6);
INSERT INTO CIR_event_has_customers VALUES (5, 7);
INSERT INTO CIR_event_has_customers VALUES (5, 8);
INSERT INTO CIR_event_has_customers VALUES (5, 9);
INSERT INTO CIR_event_has_customers VALUES (5, 10);
INSERT INTO CIR_event_has_customers VALUES (2, 6);
INSERT INTO CIR_event_has_customers VALUES (1, 7);
INSERT INTO CIR_event_has_customers VALUES (3, 13);
INSERT INTO CIR_event_has_customers VALUES (3, 12);
INSERT INTO CIR_event_has_customers VALUES (3, 6);
INSERT INTO CIR_event_has_customers VALUES (3, 8);
INSERT INTO CIR_event_has_customers VALUES (9, 11);
INSERT INTO CIR_event_has_customers VALUES (9, 10);
INSERT INTO CIR_event_has_customers VALUES (2, 5);
INSERT INTO CIR_event_has_customers VALUES (4, 7);
INSERT INTO CIR_event_has_customers VALUES (4, 2);
INSERT INTO CIR_event_has_customers VALUES (4, 13);
INSERT INTO CIR_event_has_customers VALUES (4, 10);
INSERT INTO CIR_event_has_customers VALUES (12, 7);
INSERT INTO CIR_event_has_customers VALUES (6, 14);
commit;
